emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/objed 1b7af5b 8/9: Change some default bindings


From: Clemens Radermacher
Subject: [elpa] externals/objed 1b7af5b 8/9: Change some default bindings
Date: Fri, 1 Mar 2019 15:30:44 -0500 (EST)

branch: externals/objed
commit 1b7af5b87b5589e84a538c67fcc3d366f784be30
Author: Clemens Radermacher <address@hidden>
Commit: Clemens Radermacher <address@hidden>

    Change some default bindings
---
 README.asc                                  | 15 +++++++++------
 objed.el                                    | 22 ++++++++++------------
 test/tests/emacs-lisp-mode/state/npsfsb_pop |  2 +-
 test/tests/emacs-lisp-mode/state/rrrpop     |  2 +-
 4 files changed, 21 insertions(+), 20 deletions(-)

diff --git a/README.asc b/README.asc
index 42cc953..2b335e7 100644
--- a/README.asc
+++ b/README.asc
@@ -258,6 +258,9 @@ command mark all instances in current defun/buffer):
 |kbd:[_]
 |Switch to symbol object.
 
+|kbd:[l]
+|Switch to line object.
+
 |kbd:[c]
 |Prefix to switch to other objects, see `objed-object-map` for available 
objects and `objed-define-object` to add your own 
(https://with-emacs.com/posts/objed/writing-your-own-text-objects-for-objed/[blog]).
 |===
@@ -359,13 +362,13 @@ Misc commands:
 |kbd:[q]
 |Quit window if not the only one.
 
-|kbd:[l]
+|kbd:[u]
 |Pop to last state, which restores the last position and any object data.
 
 |kbd:[M-o]
 |Choose an instance of current object type with completion, using the contents 
of the first line for completion.
 
-|kbd:[`]
+|kbd:[z]
 |Choose an instance of current object type on the screen with `avy` 
(https://with-emacs.com/posts/objed/jump-around-emacs-version/[blog]).
 
 |kbd:[m]
@@ -404,14 +407,14 @@ You can add your own prefix bindings using 
`objed-define-dispatch`.
 |kbd:[#]
 |Switch to another object using `avy`.
 
-|kbd:[u]
+|kbd:[+]
 |Activate part from point forward until boundary of some object.
 
-|kbd:[z]
+|kbd:[-]
 |Activate part from point backward until boundary of some object.
 
-|kbd:[-/+]
-|Extend current object forward/backward by including leading/trailing 
whitespace.
+|kbd:address@hidden
+|Extend current object by including trailing whitespace.
 |===
 
 
diff --git a/test/tests/emacs-lisp-mode/state/npsfsb_pop 
b/test/tests/emacs-lisp-mode/state/npsfsb_pop
index e61b6ec..32b8537 100644
--- a/test/tests/emacs-lisp-mode/state/npsfsb_pop
+++ b/test/tests/emacs-lisp-mode/state/npsfsb_pop
@@ -1,4 +1,4 @@
-npsfsbllllll
+npsfsbuuuuuu
 ;;;;
 
 Testing |line here
diff --git a/test/tests/emacs-lisp-mode/state/rrrpop 
b/test/tests/emacs-lisp-mode/state/rrrpop
index 71610ff..2a7f732 100644
--- a/test/tests/emacs-lisp-mode/state/rrrpop
+++ b/test/tests/emacs-lisp-mode/state/rrrpop
@@ -1,4 +1,4 @@
-rrrl
+rrru
 ;;;;
 
 Testing line he|re



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/objed.el b/objed.el
index 59d3bdb..755ef8d 100644
--- a/objed.el
+++ b/objed.el
@@ -695,12 +695,12 @@ BEFORE and AFTER are forms to execute before/after 
calling the command."
     (define-key map "m" 'objed-mark)
     ;; mark upwards
     (define-key map "M" 'objed-toggle-mark-backward)
-    ;; (define-key map "U" 'objed-unmark-all)
+    ;; (define-key map "M" 'objed-unmark-all)
 
     ;; "visual"
     (define-key map "v" 'objed-extend)
-    (define-key map "+" 'objed-include-trailing-ws)
-    (define-key map "-" 'objed-include-leading-ws)
+    (define-key map "@" 'objed-include-trailing-ws)
+    ;;(define-key map "-" 'objed-include-leading-ws)
 
     ;; basic edit ops
     (define-key map "k" 'objed-kill)
@@ -730,21 +730,20 @@ BEFORE and AFTER are forms to execute before/after 
calling the command."
 
     ;; direct object switches
     (define-key map "." 'objed-identifier-object)
+    (define-key map "," 'objed-goto-prev-identifier)
     (define-key map "_" 'objed-symbol-object)
+    (define-key map "l" 'objed-line-object)
     ;;(define-key map "%" 'objed-contents-object)
 
-
     ;; prefix keys
     (define-key map "x" 'objed-op-map)
     (define-key map "c" 'objed-object-map)
 
     ;; special commands
     (define-key map "*" 'objed-mark-more)
-    (define-key map "," 'objed-goto-prev-identifier)
-    (define-key map "l" 'objed-last)
-
-    ;; jump to objects with avy
-    (define-key map "`" 'objed-ace)
+    (define-key map "u" 'objed-last)
+    ;; zap to object, jump to objects with avy
+    (define-key map "z" 'objed-ace)
     ;; swiper like object search
     (define-key map (kbd "M-o") 'objed-occur)
     ;; TODO: start query replace in current object,
@@ -870,9 +869,8 @@ Use `objed-define-dispatch' to define a dispatch command.")
 
 
 (objed-define-dispatch "#" objed--ace-switch-object)
-
-(objed-define-dispatch "u" objed--backward-until)
-(objed-define-dispatch "z" objed--forward-until)
+(objed-define-dispatch "-" objed--backward-until)
+(objed-define-dispatch "+" objed--forward-until)
 
 (defun objed--backward-until (name)
   "Activate part from point backward until object NAME."